@@ -9,7 +9,7 @@ import numpy as np
 
 from ..__about__ import __version__
 from .._exceptions import ReadError, WriteError
-from .._helpers import register
+from .._helpers import register_format
 from .._mesh import CellBlock, Mesh
 
 
@@ -165,4 +165,4 @@ def write(filename, mesh, float_fmt=".16e"):
                 fh.write(fmt.format(k, *data))
 
 
-register("tetgen", [".ele", ".node"], read, {"tetgen": write})
+register_format("tetgen", [".ele", ".node"], read, {"tetgen": write})
