@@ -1,6 +1,6 @@
 """
 I/O for XDMF.
-https://www.xdmf.org/index.php/XDMF_Model_and_Format
+https://xdmf.org/index.php/XDMF_Model_and_Format
 """
 import os
 import pathlib
@@ -11,7 +11,7 @@ import numpy as np
 
 from .._common import cell_data_from_raw, raw_from_cell_data, write_xml
 from .._exceptions import ReadError, WriteError
-from .._helpers import register
+from .._helpers import register_format
 from .._mesh import CellBlock, Mesh
 from .common import (
     attribute_type,
@@ -75,7 +75,7 @@ class XdmfReader:
             data_type = data_item.attrib["NumberType"]
         else:
             # Default, see
-            # <https://www.xdmf.org/index.php/XDMF_Model_and_Format#XML_Element_.28Xdmf_ClassName.29_and_Default_XML_Attributes>
+            # <https://xdmf.org/index.php/XDMF_Model_and_Format#XML_Element_.28Xdmf_ClassName.29_and_Default_XML_Attributes>
             data_type = "Float"
 
         precision = data_item.get("Precision", default="4")
@@ -544,7 +544,7 @@ def write(*args, **kwargs):
 
 
 # TODO register all xdmf except hdf outside this try block
-register(
+register_format(
     "xdmf",
     [".xdmf", ".xmf"],
     read,
